pub fn plan_push(
request: PushRequest<'_>,
services: &mut PushServices<'_>,
) -> Result<PushPlan>Expand description
Negotiate with the remote and compute the receive-pack command list without sending a pack or applying a ref update.
pub fn plan_push(
request: PushRequest<'_>,
services: &mut PushServices<'_>,
) -> Result<PushPlan>Negotiate with the remote and compute the receive-pack command list without sending a pack or applying a ref update.