pub struct CloneServices<'a> {
pub configure: &'a mut dyn FnMut(&Path) -> Result<GitConfig>,
pub configure_branch: &'a mut dyn FnMut(&Path, &str) -> Result<GitConfig>,
pub credentials: &'a mut dyn CredentialProvider,
pub progress: &'a mut dyn ProgressSink,
}Expand description
Mutable seams used while cloning.
Fields
configure: &'a mut dyn FnMut(&Path) -> Result<GitConfig>Callback that writes initial repository config and returns the resulting config snapshot used for the fetch.
configure_branch: &'a mut dyn FnMut(&Path, &str) -> Result<GitConfig>Callback that writes local branch upstream config and returns the config snapshot used for checkout filtering.
credentials: &'a mut dyn CredentialProviderCredential source for authenticated transports.
progress: &'a mut dyn ProgressSinkProgress sink for fetch progress/prune notices.