FetchRequest

Struct FetchRequest 

pub struct FetchRequest<'a> {
    pub git_dir: &'a Path,
    pub format: ObjectFormat,
    pub config: &'a GitConfig,
    pub remote_name: &'a str,
    pub source: &'a FetchSource,
    pub refspecs: &'a [String],
    pub options: &'a FetchOptions,
}
Fully resolved inputs for a fetch run.

Fields

git_dir: &'a Path

Local repository $GIT_DIR.

format: ObjectFormat

Local repository object format.

config: &'a GitConfig

Local repository config snapshot.

remote_name: &'a str

Remote name or source string used for config lookup and FETCH_HEAD.

source: &'a FetchSource

Already-resolved transport source.

refspecs: &'a [String]

Refspecs requested by the caller. Empty means configured fetch refspecs, falling back to HEAD.

options: &'a FetchOptions

Fetch behavior flags.