PruneRefsInput

Struct PruneRefsInput 

pub struct PruneRefsInput<'a> {
    pub config: &'a GitConfig,
    pub store: &'a FileRefStore,
    pub remote: &'a str,
    pub advertisements: &'a [RefAdvertisement],
    pub refspecs: &'a [RefSpec],
    pub dry_run: bool,
    pub quiet: bool,
}
Prune refs whose destinations are covered by the active fetch refspecs and whose corresponding remote sources are absent from advertisements, deleting them and emitting git’s notice lines through progress (unless quiet). Returns the refs that were pruned.

Fields

config: &'a GitConfigstore: &'a FileRefStoreremote: &'a stradvertisements: &'a [RefAdvertisement]refspecs: &'a [RefSpec]dry_run: boolquiet: bool