PushPackRequest

Struct PushPackRequest 

pub struct PushPackRequest<'a> {
    pub local_db: &'a FileObjectDatabase,
    pub format: ObjectFormat,
    pub commands: &'a [ReceivePackCommand],
    pub pack_objects: &'a [ObjectId],
    pub remote_advertisements: &'a [RefAdvertisement],
    pub features: &'a ReceivePackFeatures,
    pub options: ReceivePackPushRequestOptions,
    pub thin: bool,
}
Inputs for building a push packfile or full receive-pack request body.

Fields

local_db: &'a FileObjectDatabase

Local object database supplying objects to pack.

format: ObjectFormat

Object format of PushPackRequest::local_db.

commands: &'a [ReceivePackCommand]

Planned receive-pack ref updates (only non-null new_id roots are packed).

pack_objects: &'a [ObjectId]

Optional explicit pack roots supplied by an embedder-authored push plan. When empty, non-null command new_ids are used.

remote_advertisements: &'a [RefAdvertisement]

Remote ref advertisements used to exclude objects the remote already has.

features: &'a ReceivePackFeatures

Negotiated receive-pack features (honours ReceivePackFeatures::no_thin).

options: ReceivePackPushRequestOptions

Receive-pack request options (capabilities, push-options, etc.).

thin: bool

When true, omit delta bases the remote is assumed to already have.