pub struct PushPlan {
pub commands: Vec<ReceivePackCommand>,
/* private fields */
}Expand description
A push after ref negotiation and command planning, but before any ref update is sent or applied.
Fields
commands: Vec<ReceivePackCommand>The receive-pack commands that will be executed if the caller proceeds.