pub struct RemoteHelperFetchDiscovery { /* private fields */ }Expand description
A live helper after capability and ref discovery, before any import or local object/ref mutation. Clone can finalize its provisional repository’s object format and then continue this same protocol process.
Implementations
Sourceimpl RemoteHelperFetchDiscovery
impl RemoteHelperFetchDiscovery
pub fn object_format(&self) -> ObjectFormat